@@ -82,3 +82,6 @@ class GameObject(ABC) :
     def end(self):
         pass
 
+    def onCollision(self,o):
+        for c in self.Components :
+            c.onCollide(o)
